#!/usr/bin/env python3
from flask import Flask
from flask_restful import Api
import sentry_sdk
from sentry_sdk.integrations.flask import FlaskIntegration

from redis_client import redis_client
from config import Config
from marshm import ma
from resources import SampleResource

"""
Main Flask RESTful API
"""

__author__ = "@tormakris"
__copyright__ = "Copyright 2021, KMLabz Team"
__module_name__ = "app"
__version__text__ = "1"

if Config.SENTRY_DSN:
    sentry_sdk.init(
        dsn=Config.SENTRY_DSN,
        integrations=[FlaskIntegration()],
        traces_sample_rate=0.0,
        send_default_pii=True,
        release=Config.RELEASE_ID,
        environment=Config.RELEASEMODE
    )

app = Flask(__name__)
app.config.from_object(Config)

api = Api(app)
ma.init_app(app)

redis_client.init_app(app)


api.add_resource(SampleResource, "/input")


if __name__ != '__main__':
    import logging

    gunicorn_logger = logging.getLogger('gunicorn.error')
    app.logger.handlers = gunicorn_logger.handlers
    app.logger.setLevel(gunicorn_logger.level)
